@@ -29,7 +29,7 @@ use crate::geom::Line;
 use crate::geom::Rect;
 use crate::geom::Size;
 
-#[derive(Copy, Clone, Debug)]
+#[derive(Copy, Clone, Debug, PartialEq)]
 pub struct Point<N: Num = f32>(pub N, pub N);
 
 // Point Speicifc functions.
@@ -425,12 +425,6 @@ impl<N: Num> Into<(N, N)> for Point<N> {
     }
 }
 
-impl<N: Num> PartialEq for Point<N> {
-    fn eq(&self, other: &Self) -> bool {
-        self.0 == other.0 && self.1 == other.1
-    }
-}
-
 #[cfg(test)]
 mod flip_x {
     use super::*;
